@@ -16,22 +16,15 @@ package Mail::DKIM::Algorithm::rsa_sha1;
 use base "Mail::DKIM::Algorithm::Base";
 use Carp;
 use MIME::Base64;
-use Digest::SHA1;
+use Digest::SHA;
 
 sub init_digests
 {
 	my $self = shift;
 
 	# initialize a SHA-1 Digest
-	$self->{header_digest} = new Digest::SHA1;
-	if ($self->{draft_version} eq "01")
-	{
-		$self->{body_digest} = new Digest::SHA1;
-	}
-	else
-	{
-		$self->{body_digest} = $self->{header_digest};
-	}
+	$self->{header_digest} = Digest::SHA->new(1);
+	$self->{body_digest} = Digest::SHA->new(1);
 }
 
 sub sign
@@ -60,4 +53,9 @@ sub verify
 	return $self->check_body_hash;
 }
 
+sub wants_pre_signature_headers
+{
+	return 1;
+}
+
 1;
